#
# spec file for package lxsession
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxsession
Version:        0.5.5+56
Release:        1.1
Summary:        LXDE Session Manager, required for running the desktop environment
License:        GPL-2.0-only
Group:          System/GUI/LXDE
URL:            http://www.lxde.org/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  dbus-1-glib-devel
BuildRequires:  docbook-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libgee-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  polkit-devel
BuildRequires:  vala >= 0.16
Obsoletes:      lxpolkit <= 0.1.0
Obsoletes:      lxsession-edit <= 0.2.0
Provides:       lxpolkit > 0.1.0
Provides:       lxsession-edit > 0.2.0

%description
LXSession is the standard session manager used by LXDE. The LXSession manager
is used to automatically start a set of applications and set up a working desktop
environment. Moreover, the session manager is able to remember the applications in
use when a user logs out and to restart them the next time the user logs in.

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
	--enable-man
%make_build

%install
%make_install
%find_lang %{name}

# fix icon problems
# no such icon lxsession-default-apps
sed -i "3d" %{buildroot}%{_datadir}/applications/lxsession-default-apps.desktop
# why lxde use xfwm4 icon ?
sed -i "3d" %{buildroot}%{_datadir}/applications/lxsession-edit.desktop

%fdupes %{buildroot}

%files -f %{name}.lang
%license COPYING
%doc AUTHORS ChangeLog README TODO
%{_bindir}/lxlock
%{_bindir}/lxsession
%{_bindir}/lxsession-logout
%{_bindir}/lxclipboard
%{_bindir}/lxpolkit
%{_bindir}/lxsession-default
%{_bindir}/lxsession-default-apps
%{_bindir}/lxsession-default-terminal
%{_bindir}/lxsession-xdg-autostart
%{_bindir}/lxsession-edit
%{_bindir}/lxsession-db
%{_bindir}/lxsettings-daemon
%{_datadir}/lxsession/
%{_datadir}/applications/lxsession-default-apps.desktop
%{_datadir}/applications/lxsession-edit.desktop
%{_mandir}/man1/*.1%{?ext_man}
%{_sysconfdir}/xdg/autostart/lxpolkit.desktop
%dir %{_libexecdir}/lxsession
%{_libexecdir}/lxsession/lxsession-xsettings

%changelog
* Mon Nov 18 2024 bjorn.lie@gmail.com
- Update to version 0.5.5+56:
  * Remove trailing whitespace in man pages
  * Fix spelling and update man page
  * Increase the required versions of GLib and GTK+
  * Update autogen.sh
  * Remove the obsolete debian directory
  * Remove the m4 directory
  * Remove the comment about the order of checked screen lockers
  * Fix description of the --enable-debug option
  * Reduce the vala compiler version check to major and minor version
  * Fix: support gcc14 -Werror=incompatible-pointer-types
- Switch to gitcheckout via source service.
- Pass NOCONFIGURE=1 ./autogen.sh, bootstrap build.
* Mon Sep 28 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Sat Jul  4 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.5.5:
  * Remove libunique dependency
  * Resolve correctness and memory handling issues
  * Translation updates
  * Pass desktop_environment as a parameter to
    lxsession-xdg-autostart to fix wrong autostart processing
- includes changes from 0.5.4:
  * Drop attempt to run dbus-launch in code
* Sun Dec 25 2016 trcs@gmx.com
- New upstream version 0.5.3
  * Made possible to add custom environment variable export
  * Added im manager handler
  * Few fixes for GTK+ 3.0
  * Few changes in desktop entries to better fit into DE other than
    LXDE
  * Added notifications system support using appindicator
  * Fixed handling the background of logout dialog
  * Added messages for lxpolkit and lxclipboard when they are already
    running
  * Fixed config settings when second key is null
  * Fixed lxsession-logout on multihead
  * Fixed possible hanging of lxsession-logout
  * Added slimlock support on lxlock
  * Fixed invisible caracter in lxpolkit
  * Use Consolekit new interface to suspend / hibernate
  * Added support to disable gtk+ 3 overlay scrollbar
  * Added missing read_key_value for environment keys
  * Added Qt platform configuration settings
  * Remove empty string after windows manager command. Some windows
    manager (xmonad) don't like it and it doesn't really make sense
    by default
  * Don't save desktop.conf file on every load settings when starting
    lxsession, it's not necessary since lxsession only needs to read
    settings at startup
  * Moved lxsession-xsettings into $pkglibexecdir
  * Fixed two spelling errors
* Sun Nov 30 2014 trcs@gmx.com
- New upstream version 0.5.2
  * Use <binarytarget>_CPPFLAGS instead of <binarytarget>_CFLAGS
  * If .c files are in CLEANFILES then .stamp files should be there
    too
  * Fix FSF address (fix #697)
  * Fix lock in lxsession-default and add lock_manager option in
    lxsession-default (fix #705)
  * Fix gtk3 compilation, and merge patches #454 and #453
  * Add .c files generated by vala, to be able to pass --enable
    flags
  * Create lock file to prevent more than one logout dialog (patch
    from Martin Thornton #456)
  * Added ESCAPE key to close the lxsession-logout menu
  * Add some environment variables for LXQt and Qt
  * Fix duplicate lxpolkit invocation by setting Hidden=true in
    lxpolkit.desktop.
  * Correctly connect and emit signals for lxsession-db (should
    really fix #692)
  * Translation updates
  * patches removed since now in upstream code
    + lxsession-0.5.1-duplicate-lxpolkit-invocation-fix.patch
    + lxsession-0.5.1-lxsession-db-SF692-fix.patch
  * Raise VALAC version requirement, it doesn't compile with 0.14,
    needs 0.16
  * Applied spec-clean
* Thu Oct 23 2014 trcs@gmx.com
- added
  * lxsession-0.5.1-duplicate-lxpolkit-invocation-fix.patch
  * lxsession-0.5.1-lxsession-db-SF692-fix.patch
* Tue Oct 21 2014 andrea@opensuse.org
- New upstream version 0.5.1
  * patches removed since now in upstream code
  - lxsession-0.4.9.3-gtk3-hide_all.patch
  - lxsession-0.4.9.3-gtk3-fix.patch
  - lxsession-0.4.9.3-lower-libgee.patch
  * Translations updates.
  * Added support for reboot and shutdown in LTST client.
  * Added support for user switch.
  * Added clipboard support, based on Xfce one.
  * Added options to launch default applications.
  * Rewritten whole lxsession in Vala.
  * Implemented a connection to session bus.
  * Added ability to change settings by Dbus call,
    example by keymap configuration.
  * full changelog : http://blog.lxde.org/?p=1283
* Tue Mar 25 2014 andrea@opensuse.org
- provide and obsolete lxsession-edit and lxpolkit
* Thu Mar 20 2014 trcs@gmx.com
- Built against GKT2 to override GTK3 issues
  * fixes theming issues
  * avoid mixing LXDE packages built with GTK2 and GTK3
- Removed build compatibility with discontinued versions (<= 12.2)
  * Removed unneeded lxsession-0.4.9.3-FileAttribute.Standard_Name.patch
    patch
* Sat Sep 14 2013 i@marguerite.su
- update version 0.4.9.3.git20130914
  * various bugfix release
  * 0.4.9.2 has a bug, shutdown/reboot doesn't work
  * upstream rewrite the dbus interface, so no way to find
    a "fix" unless we update it. (bnc#839854)(sf#3614478)
- add patch: lxsession-0.4.9.3-lower-libgee.patch
  * because it's no sense to update it
- add patch: lxsession-0.4.9.3-gtk3-fix.patch
  * it used gtk2 to generate C files from vala, then build
    with gtk3. that's shit
- add patch: lxsession-0.4.9.3-gtk3-hide_all.patch
  * gtk_widget_hide_all() is no more in gtk3, replace with
    hide()
- add patch: lxsession-0.4.9.3-FileAttribute.Standard_Name.patch
  * FileAttribute.Standard_Name is still File_Attribute_Standard_Name
    in vala 0.14
  * can't use the same name for elements of the same type in a single
    function in vala 0.14 (gnome#596861)
* Wed Sep  4 2013 i@marguerite.su
- update version 0.4.9.2
  * bugfix release
- removed all 0.4.6.1 patches, upstreamed
  * lxsession-0.4.6.1-support-reboot-shutdown-ltst.patch
  * lxsession-0.4.6.1-support-user-switch-gdm3.patch
- build with gtk3 on 12.3+ machines
- add patch: lxsession-0.4.9.2-gtk3-fix.patch
  * gtkobject is no more in gtk3, fix with gobject.
  * gtk_widget_hide_all is no more, fix with gtk_widget_hide
* Fri Jul 29 2011 andrea@opensuse.org
- added lxsession-0.4.6.1-support-user-switch-gdm3.patch to
  allow lxsession-logout to work properly with gdm3 (upstream)
- added lxsession-0.4.6.1-support-reboot-shutdown-ltst.patch to
  add proper support to ltst clients (upstream)
* Fri Jul 29 2011 andrea@opensuse.org
- upstream bugfix release 0.4.6.1
- removed %%name-0.4.6-fix-crash-on-start.patch now in
  upstream code
* Sun Jul 24 2011 andrea@opensuse.org
- new upstream version 0.4.6
  * translations updates
  * bug fix
  * gtk3 support
- added lxsession-0.4.6-fix-crash-on-start.patch
- removed lockscreen patch now in upstream code
* Mon May 30 2011 andrea@opensuse.org
- removed hal from buildrequires, fixed bnc 697010
* Sat Dec  4 2010 gber@opensuse.org
- take a different approach to locking the screen, execute a lxlock
  script asynchronously, this solves the problem with xlock and
  slock which do not fork and blocked suspend/hibernate
* Tue Nov 16 2010 gber@opensuse.org
- rebased lxsession-0.4.4-fix-bnc627416.patch for 0.4.5
* Tue Nov 16 2010 andrea@opensuse.org
- new upstream version 0.4.5
  * bug fix release
  * all previous patches used from git code are now included
    into this tarball
  * fixed some crasch
  * translations updates
* Mon Jul 26 2010 andrea@opensuse.org
- backport from upstream lxsession-0.4.4-fix-bnc627416.patch
  lxsession-logout can finally fully work without HAL
  (using UPower) fixed bnc#627416
* Sat Jul 17 2010 guido+opensuse.org@berhoerster.name
- refine patch for bnc#622083
* Sat Jul 17 2010 andrea@opensuse.org
- added lxsession-0.4.4-fix-bnc623192.patch to fix upstream
  bug sf#3030576 (bnc#623192)
* Wed Jul 14 2010 andrea@opensuse.org
- spec file clean up
* Tue Jul 13 2010 guido+opensuse.org@berhoerster.name
- lock screen when suspending/hibernating/switching users, fixes
  bnc#622083
* Mon Jun  7 2010 andrea@opensuse.org
- changed RPM Group to System/GUI/LXDE
* Mon Apr  5 2010 andrea@opensuse.org
- new upstream version 0.4.4
  - bug fixes
  - added LTSP (Linux Terminal Server Project) support
  - removed un-used gdm source code
- removed lxsession-0.4.3-fix-buttons-position.patch
  because has been merged upstream
* Thu Mar 18 2010 andrea@opensuse.org
- new upstream version 0.4.3
- removed fortify-declaration patch (fixed upstream)
- ported lxsession-0.4.2-fix-buttons-position.patch to fit new code
- bug fix release
* Thu Mar 11 2010 andrea@opensuse.org
- added lxsession-0.4.2-fix-buttons-position.patch to properly set
  lxsession-logout buttons
* Mon Mar  8 2010 andrea@opensuse.org
- new upstream version 0.4.2
  * Fix incorrect configure message for missing dbus
  * Major rewrite of lxsession-logout
  - Convert to using only one toplevel window to solve Compiz
    drawing over the controls
  - Add support for shutdown/reboot via ConsoleKit
  - Query HAL for capabilities rather than assuming they are
    present if HAL is
  - Latent (untested) support for suspend/hibernate via
    DeviceKit/Power
  - Remove GDM communication mechanism that was discontinued
    in GDM 2.22
* Fri Dec 11 2009 andrea@opensuse.org
-  new upstream version 0.4.1 (bug fix release)
* Tue Dec  8 2009 andrea@opensuse.org
- new upstream stable version 0.4.0
* Fri Jul 17 2009 Andrea Florio <andrea@opensuse.org> 0.4.0svn.1835
- upgrade to svn 1835, lxde-settings-daemon now obsoletes
* Sat May 23 2009 Andrea Florio <andrea@opensuse.org> 0.3.8
- New package
